@@ -141,7 +141,7 @@ int Choose(int n, int k, int *C){int x;
  */
 /*---QUICK-FIX----------------------------------------------------------------*/
 
-void DivClassBasis(FILE *SF,PolyPointList *P,int v,char *D,char *B){
+void DivClassBasis(int SF,PolyPointList *P,int v,char *D,char *B){
   Long cdiv=0, sv, nok, *X[POLY_Dmax]; int d=P->n, C[VERT_Nmax];
   nok=Init_Choose(v,d,C);
   do { int c, CC[VERT_Nmax];
@@ -150,11 +150,11 @@ void DivClassBasis(FILE *SF,PolyPointList *P,int v,char *D,char *B){
     else for(c=0;c<d;c++) CC[c]=v-1-C[c];	/* eliminate D_max first */
     for(c=0;c<d;c++) X[c]=P->x[CC[c]];
     sv=SimplexVolume(X,P->n); cdiv=NNgcd(cdiv,sv);
-    if(sv==1){int x=0; fprintf(SF,"\nideal DCbase=");
+    if(sv==1){int x=0; dprintf(SF,"\nideal DCbase=");
       Inci64 I=makeN(CC[0]); for(c=1;c<d;c++) I+=makeN(CC[c]);
-      for(c=0;c<v;c++) if(!getN(c,I)) {if(x) fprintf(SF,","); /* complement */ 
-	fprintf(SF,"%s%d-%s%d",B,++x,D,c+1);} 
-      assert(x==v-d); fprintf(SF,";\n"); return; }
+      for(c=0;c<v;c++) if(!getN(c,I)) {if(x) dprintf(SF,","); /* complement */ 
+	dprintf(SF,"%s%d-%s%d",B,++x,D,c+1);} 
+      assert(x==v-d); dprintf(SF,";\n"); return; }
     nok--;} while(Choose(v,d,C)); assert(nok==0);
 
   if(cdiv>1){
@@ -166,17 +166,17 @@ void DivClassBasis(FILE *SF,PolyPointList *P,int v,char *D,char *B){
       else for(c=0;c<d;c++) CC[c]=v-1-C[c];	/* eliminate D_max first */
       for(c=0;c<d;c++) X[c]=P->x[CC[c]];
       sv=SimplexVolume(X,P->n);
-      if(sv==cdiv){int x=0; fprintf(SF,"\nideal DCbase=");
+      if(sv==cdiv){int x=0; dprintf(SF,"\nideal DCbase=");
       	Inci64 I=makeN(CC[0]); for(c=1;c<d;c++) I+=makeN(CC[c]);
-        for(c=0;c<v;c++) if(!getN(c,I)) {if(x)fprintf(SF,",");
-	  fprintf(SF,"%s%d-%s%d",B,++x,D,c+1);} 
-        assert(x==v-d); fprintf(SF,";\n"); return; }
+        for(c=0;c<v;c++) if(!getN(c,I)) {if(x)dprintf(SF,",");
+	  dprintf(SF,"%s%d-%s%d",B,++x,D,c+1);} 
+        assert(x==v-d); dprintf(SF,";\n"); return; }
       nok--;} while(Choose(v,d,C));}
 
   puts("IMPROVE CODE: no Vol=1 simplex in DivClassBasis()");exit(0);}
 
 
-void OLD_LinRelLatticeBasis(FILE *SF,PolyPointList *P,int v,char *D,char *B){
+void OLD_LinRelLatticeBasis(int SF,PolyPointList *P,int v,char *D,char *B){
   int i,j,k,l; Long cdiv=0; if(v>8) {DivClassBasis(SF,P,v,D,B);return;}
   if(P->n != 4) {DivClassBasis(SF,P,v,D,B);return;}
 
@@ -188,22 +188,22 @@ void OLD_LinRelLatticeBasis(FILE *SF,PolyPointList *P,int v,char *D,char *B){
  
 //printf("SimpVol[%d%d%d%d]=%ld\n",i,j,k,l,SimplexVolume(X,P->n));
     sv=SimplexVolume(X,P->n); cdiv=NNgcd(cdiv,sv);
-    if(sv==1) {x=0; fprintf(SF,"\nideal DCbase=");
+    if(sv==1) {x=0; dprintf(SF,"\nideal DCbase=");
       for(y=0;y<v;y++) if(!getN(y,I)) {		      /* integral basis B[] */
-        if(x) fprintf(SF,",");
-	fprintf(SF,"%s%d-%s%d",B,++x,D,y+1);} 
-      assert(x==v-4); fprintf(SF,";\n"); return;}}
+        if(x) dprintf(SF,",");
+	dprintf(SF,"%s%d-%s%d",B,++x,D,y+1);} 
+      assert(x==v-4); dprintf(SF,";\n"); return;}}
 
   if(cdiv>1){printf("Fundamental group = Z%d\n",(int)cdiv);fflush(0);
    for(l=3;l<v;l++)for(k=2;k<l;k++)for(j=1;j<k;j++)for(i=0;i<j;i++){Long *X[4];
     Inci64 I=makeN(i)+makeN(j)+makeN(k)+makeN(l); int x=0,y; Long sv;
     for(y=0;y<v;y++) if(getN(y,I)) X[x++]=P->x[y]; assert(x==4); 
     sv=SimplexVolume(X,P->n); 
-    if(sv==cdiv) {x=0; fprintf(SF,"\nideal DCbase=");
+    if(sv==cdiv) {x=0; dprintf(SF,"\nideal DCbase=");
       for(y=0;y<v;y++) if(!getN(y,I)) {		      /* integral basis B[] */
-        if(x)fprintf(SF,",");
-	fprintf(SF,"%s%d-%s%d",B,++x,D,y+1);} /* OFFSET */
-      assert(x==v-4); fprintf(SF,";\n"); return;}}
+        if(x)dprintf(SF,",");
+	dprintf(SF,"%s%d-%s%d",B,++x,D,y+1);} /* OFFSET */
+      assert(x==v-4); dprintf(SF,";\n"); return;}}
    }
   puts("IMPROVE CODE: no Vol=1 simplex in LinRelLatticeBasis!!!");exit(0);
   }
@@ -216,12 +216,6 @@ void OLD_LinRelLatticeBasis(FILE *SF,PolyPointList *P,int v,char *D,char *B){
 /* new version:	number Vol=1; poly norm=Vol*reduce(d1*d2*d3*d4*d5,chow);
  *		reduce(nef*d1*d1*d1,chow)/norm;  // D=d divisor, B=h basis
  */
-void CatFile(char *fn){char CAT[30+L_tmpnam];strcpy(CAT,"cat ");
-  strcat(CAT,fn);printf("======= FILE content of %s:\n",fn); fflush(0);
-  assert(0==system(CAT));
-  printf("====== End of FILE content of %s\n\n",fn); fflush(0);}
-
-
 
 
 /*   ==============	    M O R I   C O N E		================   */
@@ -256,7 +250,7 @@ void Print_Inci64_list(int n,Inci64 *I,int p){
 
 int Inci64_abs(Inci64 X){int abs=X%2; while(X/=2) abs+=X%2; return abs;}
 
-void IDerr(){puts("\n       ********       INPUT DATA ERROR    	  ********");}
+void IDerr(void){puts("\n       ********       INPUT DATA ERROR    	  ********");}
 
 int Make_triCD2F(triang *T,Inci64 *cd2I){int i,j,cd2n=0;
   for(i=1;i<T->n;i++)for(j=0;j<i;j++){int k; Inci64 S=T->I[i]&T->I[j];
@@ -270,14 +264,15 @@ int Make_triCD2F(triang *T,Inci64 *cd2I){int i,j,cd2n=0;
 
 int Check_Mori(PolyPointList *P,int p,triang *T){	// strongly convex(?)
   int nI=T->n; Inci64 *I=T->I, cd2F[CD2F_Nmax];
-  int i,j,r=0,d=P->n,ngen=0, ng0,nv,np; Long Z[POLY_Dmax+1]; VertexNumList V; 
+  int i,j,r=0,d=P->n,ngen=0, /*ng0,*/nv,np; Long Z[POLY_Dmax+1];
+  VertexNumList V; 
 			// int e0=0,nm=0,m[VERT_Nmax];; Inci64 IE[VERT_Nmax];
   PolyPointList *UT = (PolyPointList *) malloc(sizeof(PolyPointList));
   Matrix R,VT,G; EqList *E = (EqList*)malloc(sizeof(EqList)); 
 
   assert(E!=NULL); assert(UT!=NULL); 
   for(i=1;i<nI;i++)for(j=0;j<i;j++)ngen+=(Inci64_abs((I[i])&(I[j]))==d-1); 
-  Init_Matrix(&VT,d,d+1);Init_Matrix(&R,ngen,p);Init_Matrix(&G,p,p); ng0=ngen;
+  Init_Matrix(&VT,d,d+1);Init_Matrix(&R,ngen,p);Init_Matrix(&G,p,p);//ng0=ngen;
 assert(ngen==Make_triCD2F(T,cd2F));
   for(i=1;i<nI;i++)for(j=0;j<i;j++)if(Inci64_abs(Inci64_AND(I[i],I[j]))==d-1){
     int a,b; Inci64 Ia=I[i]|I[j]; Inci64_2_VNL(Ia,&V,p); assert(V.nv==d+1);
@@ -317,14 +312,14 @@ assert(Inci64_abs(Ia)==2); assert(b<d);
 
 
 void Print_Mori(PolyPointList *P,int p,int nI, Inci64 *I){
-  int i,j,r=0,d=P->n,ngen=0, ng0,e0=0,nm=0,nv,np; 
+  int i,j,r=0,d=P->n,ngen=0, /* ng0,*/ e0=0,nm=0,nv,np; 
   int m[VERT_Nmax]; Long Z[POLY_Dmax+1]; VertexNumList V; Inci64 IE[VERT_Nmax];
   PolyPointList *UT = (PolyPointList *) malloc(sizeof(PolyPointList));
   Matrix R,VT,G; EqList *E = (EqList*)malloc(sizeof(EqList)); 
 
   assert(E!=NULL); assert(UT!=NULL); 
   for(i=1;i<nI;i++)for(j=0;j<i;j++)ngen+=(Inci64_abs((I[i])&(I[j]))==d-1); 
-  Init_Matrix(&VT,d,d+1);Init_Matrix(&R,ngen,p);Init_Matrix(&G,p,p); ng0=ngen;
+  Init_Matrix(&VT,d,d+1);Init_Matrix(&R,ngen,p);Init_Matrix(&G,p,p);//ng0=ngen;
   for(i=1;i<nI;i++)for(j=0;j<i;j++)if(Inci64_abs(Inci64_AND(I[i],I[j]))==d-1){
     int a,b; Inci64 Ia=I[i]|I[j]; Inci64_2_VNL(Ia,&V,p); assert(V.nv==d+1);
     for(a=0;a<=d;a++) for(b=0;b<d;b++) VT.x[b][a]=P->x[V.v[a]][b]; 
@@ -567,7 +562,7 @@ int InterSectE(Long *X,Long *Y,Long *U,Long *V){
     if(xyu*uvx<0) return 1; else return -1;}
 
 void MakeVecPrim(Long *X){
-  Long g=1;if(X[0]*X[1])g=Fgcd(X[0],X[1]);
+  Long g=1; if(X[0] && X[1]) g=Fgcd(X[0],X[1]);
   if(X[2]) g=Fgcd(g,X[2]);
   if(g<0) g=-g;
   if(g>1) {X[0]/=g;X[1]/=g; X[2]/=g;}}
@@ -1034,7 +1029,7 @@ int Compatible_Tri(Inci64 CA,Inci64 CB,int a,Inci64 *A,int b,Inci64 *B,int p){
       int sum=0, j;
       for(j=0;j<ib;j++) if(IA[i]==IB[j]) sum++;
       if(sum!=1) return 0;} 
-  p=0;
+  // p=0;
   return 1;}
 
 
@@ -1253,7 +1248,7 @@ void NewtonMonomial(Long *X,int d){int num=0,den=0,i,t=NewtonMonomCOORD==1;
  */
 void HyperSurfDivisorsQ(PolyPointList *_P, VertexNumList *V, EqList *E, 
 			MORI_Flags * _Flag){
-  int i=V->nv,j, cp=_P->np-1,t=E->ne,d=_P->n, Dh0[VERT_Nmax], Dh2[VERT_Nmax]; 
+  int i=V->nv,j,cp=_P->np-1,t=E->ne,d=_P->n,Dh0[VERT_Nmax]/*,Dh2[VERT_Nmax]*/; 
   Inci64 I[VERT_Nmax], T[FACE_Nmax]; Long Wsum[VERT_Nmax];
   FibW *F = (FibW *) malloc( sizeof(FibW) );
   assert(F!=NULL);
@@ -1427,8 +1422,8 @@ void HyperSurfDivisorsQ(PolyPointList *_P, VertexNumList *V, EqList *E,
     VNL_to_DEL(_P, V, DE); 
     assert(Transpose_PM(PM,DPM,V->nv,E->ne));
     Complete_Poly(DPM,DE,E->ne,DP);
-    for(i=0;i<cp;i++)
-      Dh2[i]=SectionCount(_P,i,DP)-1;
+    //for(i=0;i<cp;i++)
+    //  Dh2[i]=SectionCount(_P,i,DP)-1;
     free(DP);
     free(DE);	//for(i=0;i<cp;i++)printf("%d ",Dh2[i]);puts("=h02");
     Subdivide(_P,V->nv,I,cp,T,&t, _Flag ,F);
@@ -1464,18 +1459,18 @@ void HyperSurfDivisorsQ(PolyPointList *_P, VertexNumList *V, EqList *E,
 
 
 
-void IFerr(){puts(
+void IFerr(void){puts(
   "\n       ************      INPUT FORMAT ERROR   	  ************");}
 
 void FE(char *c){puts("Input format error in ");puts(c);exit(0);}
 
 /*needed from Read_Tri*/
-void Read_EOL(){
+void Read_EOL(void){
 	char c;
 	while('\n'!=(c=fgetc(inFILE)))	if(feof(inFILE))FE("EOF");
 }
 
-int  ReadInt()
+int  ReadInt(void)
 {    int n; char c=fgetc(inFILE); if(!IsDigit(c)&&(c!='-')) FE("ReadInt");
      ungetc(c,inFILE); fscanf(inFILE,"%d",&n);
      while(' '==(c=fgetc(inFILE)));
@@ -1558,14 +1553,14 @@ Inci64 Inci64_revert(Inci64 X, int n) {
 }
 
 void Print_Mori_Old(PolyPointList *P,int nI, Inci64 *I){
-  int i,j,k,r=0,d=P->n,p=P->np, ngen=0, pli[POLY_Dmax+1],ng0,e0=0,nm=0,nv,np;
+  int i,j,k,r=0,d=P->n,p=P->np,ngen=0,pli[POLY_Dmax+1],/*ng0,*/e0=0,nm=0,nv,np;
   int m[VERT_Nmax]; Long Z[POLY_Dmax+1]; VertexNumList V; Inci64 IE[VERT_Nmax];
   PolyPointList *UT = (PolyPointList *) malloc(sizeof(PolyPointList));
   Matrix R,VT,G; EqList *E = (EqList*)malloc(sizeof(EqList));
   assert(E!=NULL); assert(UT!=NULL);
   for(i=1;i<nI;i++) for(j=0;j<i;j++)
 		      ngen+=(Inci64_abs(Inci64_AND(I[i],I[j]))==d);
-  Init_Matrix(&VT,d,d+1);Init_Matrix(&R,ngen,p);Init_Matrix(&G,p,p); ng0=ngen;
+  Init_Matrix(&VT,d,d+1);Init_Matrix(&R,ngen,p);Init_Matrix(&G,p,p); //ng0=ngen;
   for(i=1;i<nI;i++) for(j=0;j<i;j++) if(Inci64_abs(Inci64_AND(I[i],I[j]))==d) {
     int a,b,x; INCI_2_VNL(I[j],&V,p); assert(V.nv==d+1);
     for(k=0;k<=d;k++) pli[k]=V.v[k];
@@ -1648,7 +1643,7 @@ long long Compute_Abi(PolyPointList *P){
 }
 
 void ComputeStanleyReisner(PolyPointList *P,int nI,Inci64 *I, int *NrInz, Inci64 *SRG, long long Abi){
-  Inci64 *IV, *A, *B, *G[POLY_Dmax], *M, *N;
+  Inci64 *IV, *A, *B, /* *G[POLY_Dmax],*/ *M, *N;
   int i=1,j=P->np/2, m,n, nG[POLY_Dmax+1], g=0,d,v=P->np-1; if(j>P->n)j=P->n+1;
   //bico=P->np; while(i<j) {bico*=(P->np-i); bico/=++i;} 
   assert(P->np<VERT_Nmax);
@@ -1656,11 +1651,11 @@ void ComputeStanleyReisner(PolyPointList *P,int nI,Inci64 *I, int *NrInz, Inci64
   IV=(Inci64 *) malloc( v*sizeof(Inci64) );// SRG = (Inci64 *) malloc( Abi ),
   assert(SRG!=NULL); assert(IV!=NULL); assert(A!=NULL); assert(B!=NULL);
   IV[0]=Inci64_1(); for(i=1;i<v;i++) IV[i]=Inci64_PN(IV[i-1],1); M=A; m=0; N=B;
-  G[2]=&SRG[g]; nG[2]=0;
+  /* G[2]=&SRG[g]; */ nG[2]=0;
   for(i=1;i<v;i++)for(j=0;j<i;j++) M[m++]=Inci64_OR(IV[i],IV[j]);
   for(i=0;i<m;i++){for(j=0;j<nI;j++) if(Inci64_LE(M[i],I[j]))break;
     if(j==nI) {SRG[g++]=M[i];nG[2]++;}}
-  for(d=3;d<=P->n+1;d++){n=0; nG[d]=0; G[d]=&SRG[g];
+  for(d=3;d<=P->n+1;d++){n=0; nG[d]=0; // G[d]=&SRG[g];
     for(i=0;i<m;i++){int l=0;
       while(!Inci64_LE(IV[l],M[i])) N[n++]=Inci64_OR(IV[l++],M[i]);}
     for(i=0;i<n;i++){for(j=0;j<nI;j++) if(Inci64_LE(N[i],I[j]))break;
