@@ -1584,11 +1584,11 @@ if(vNF){printf("vNF[%d]=%d was=%d v_new=%d\n",v,xvNF,vNF,DB->v);exit(0);}
      AuxGet_uc(DB->Fv[DB->v],&DB->nu,uc); ++DB->p; totNF++; return 1;
 }
 
-int  Read_SLucNF_from_DB( /* DataBase *DB,unsigned char *uc */ )
+int  Read_SLucNF_from_DB(void)
 {    puts("Read_SLucNF_from_DB: to be implemented"); exit(0); return 0;
 }
 
-int  Read_SLpoly_from_DB( /* DataBase *DB,unsigned char *uc */ )
+int  Read_SLpoly_from_DB(void)
 {    puts("Read_SLpoly_from_DB: to be implemented"); exit(0); return 0;
 }
 
@@ -1700,7 +1700,7 @@ void Aux_Make_Dual(PolyPointList *P, VertexNumList *V, EqList *E)
      for(i=0;i<v;i++){for(j=0;j<d;j++)E->e[i].a[j]=VM[i][j]; E->e[i].c=1;}
      assert(Ref_Check(P,V,E));
 }
-void PrintVPHMusage();
+void PrintVPHMusage(void);
 int  Make_Lattice_Basis(int d, int p, Long *P[POLY_Dmax],  /* index=det(D) */
         Long G[][POLY_Dmax], Long *D);/* G x P generates diagonal lattice D */
 void PH_Sublat_Polys(char *dbin, int omitFIP, PolyPointList *_P, char sF) 
@@ -1797,7 +1797,7 @@ void VPHM_Sublat_Polys(char sFlag,char mr,char *dbin,char *polyi,char *polyo,
         else{puts("-s# requires that # is in {v,p,h,b,m,q}");PrintVPHMusage();
      } }
 }
-void PrintVPHMusage()
+void PrintVPHMusage(void)
 {puts("	-sh ... gen by codim>1 points (omit IPs of facets)");
  puts("	-sp ... gen by all points");
  puts("	-sb ... generated by dim<=1 (edges), print if rank=2	");
