@@ -20,7 +20,7 @@
 FILE *inFILE, *outFILE;
 
 void  PrintUsage(char *c){
-  printf("This is ``mori.x'':  star triangulations of a polytope P* in N\n");
+  printf("This is ``%s'':  star triangulations of a polytope P* in N\n",c);
   printf("                     Mori cone of the corresponding toric ambient spaces\n");
   printf("                     intersection rings of embedded (CY) hypersurfaces\n");
   printf("Usage:   %s [-<Option-string>] [in-file [out-file]]\n", c);
@@ -181,7 +181,8 @@ int main (int narg, char* fn[]){
       if (POLY_Dmax  < (_P->np - _P->n)){
 	printf("Please increase POLY_Dmax to at least %d = %d - %d - 1\n",
 	       (_P->np - _P->n -1), _P->np, _P->n);
-	puts("(mori.x -M requires POLY_Dmax >= #(points) - dim N -1)");
+	printf("(%s -M requires POLY_Dmax >= #(points) - dim N -1)\n",
+	       fn[0]);
 	exit(0);      }   }
     HyperSurfDivisorsQ(_P,&V,E,&Flag);
     fflush(outFILE);  }
